// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

var DotNetSupportLib = {
	$DOTNET: {
		conv_string: function (mono_obj) {
			return MONO.string_decoder.copy (mono_obj);
		}
	},
	mono_wasm_invoke_js_blazor: function(exceptionMessage, callInfo, arg0, arg1, arg2)	{
		var mono_string = globalThis._mono_string_cached
			|| (globalThis._mono_string_cached = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']));

		try {
			var blazorExports = globalThis.Blazor;
			if (!blazorExports) {
				throw new Error('The blazor.webassembly.js library is not loaded.');
			}

			return blazorExports._internal.invokeJSFromDotNet(callInfo, arg0, arg1, arg2);
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	},

	// This is for back-compat only and will eventually be removed
	mono_wasm_invoke_js_marshalled: function(exceptionMessage, asyncHandleLongPtr, functionName, argsJson, treatResultAsVoid) {

		var mono_string = globalThis._mono_string_cached
			|| (globalThis._mono_string_cached = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']));

		try {
			// Passing a .NET long into JS via Emscripten is tricky. The method here is to pass
			// as pointer to the long, then combine two reads from the HEAPU32 array.
			// Even though JS numbers can't represent the full range of a .NET long, it's OK
			// because we'll never exceed Number.MAX_SAFE_INTEGER (2^53 - 1) in this case.
			//var u32Index = $1 >> 2;
			var u32Index = asyncHandleLongPtr >> 2;
			var asyncHandleJsNumber = Module.HEAPU32[u32Index + 1]*4294967296 + Module.HEAPU32[u32Index];

			// var funcNameJsString = UTF8ToString (functionName);
			// var argsJsonJsString = argsJson && UTF8ToString (argsJson);
			var funcNameJsString = DOTNET.conv_string(functionName);
			var argsJsonJsString = argsJson && DOTNET.conv_string (argsJson);

			var dotNetExports = globaThis.DotNet;
			if (!dotNetExports) {
				throw new Error('The Microsoft.JSInterop.js library is not loaded.');
			}

			if (asyncHandleJsNumber) {
				dotNetExports.jsCallDispatcher.beginInvokeJSFromDotNet(asyncHandleJsNumber, funcNameJsString, argsJsonJsString, treatResultAsVoid);
				return 0;
			} else {
				var resultJson = dotNetExports.jsCallDispatcher.invokeJSFromDotNet(funcNameJsString, argsJsonJsString, treatResultAsVoid);
				return resultJson === null ? 0 : mono_string(resultJson);
			}
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	},

	// This is for back-compat only and will eventually be removed
	mono_wasm_invoke_js_unmarshalled: function(exceptionMessage, funcName, arg0, arg1, arg2)	{
		try {
			// Get the function you're trying to invoke
			var funcNameJsString = DOTNET.conv_string(funcName);
			var dotNetExports = globalThis.DotNet;
			if (!dotNetExports) {
				throw new Error('The Microsoft.JSInterop.js library is not loaded.');
			}
			var funcInstance = dotNetExports.jsCallDispatcher.findJSFunction(funcNameJsString);

			return funcInstance.call(null, arg0, arg1, arg2);
		} catch (ex) {
			var exceptionJsString = ex.message + '\n' + ex.stack;
			var mono_string = Module.cwrap('mono_wasm_string_from_js', 'number', ['string']); // TODO: Cache
			var exceptionSystemString = mono_string(exceptionJsString);
			setValue (exceptionMessage, exceptionSystemString, 'i32'); // *exceptionMessage = exceptionSystemString;
			return 0;
		}
	}


};

autoAddDeps(DotNetSupportLib, '$DOTNET')
mergeInto(LibraryManager.library, DotNetSupportLib)


// SIG // Begin signature block
// SIG // MIIorAYJKoZIhvcNAQcCoIIonTCCKJkCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // DQxM5aUosMIFmI353dLRcro0jWTAvinWkY5FLkoNZqCg
// SIG // gg3lMIIGYzCCBEugAwIBAgITMwAAAwTBAxl+xgXkBAAA
// SIG // AAADBDANBgkqhkiG9w0BAQwFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDExMB4XDTIyMDgwNDIwMjM1NloX
// SIG // DTIzMDgwMzIwMjM1NlowYzELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjENMAsGA1UEAxMELk5FVDCCAaIwDQYJKoZIhvcNAQEB
// SIG // BQADggGPADCCAYoCggGBAOHdTRLALlo0YXrnjKD38BEe
// SIG // NtbwT65kNWykLVVi5fg+iYy/NvqwmzM8B7jsikuqyuL5
// SIG // e9ofVzCImQrBnr8/kNWqCCRzY7BmSXPj/G6l3V4sdCvW
// SIG // W0w4phNSRODYv2llNrTrBYQ3VM8Qan7XPCiggyPpdLgI
// SIG // tgqCtUmRnhcLt+t1CJPyjBdXZsW9PEGvXp5rxEk/QjPw
// SIG // pLl0ByDhx/Q4Jl+Gt89xQISHyhp88bFpIq1hBoYX7Mj3
// SIG // MWELhURlVg9C6S7zbP4iKnRlPBaFOsWY2ZdgBdmq6SMo
// SIG // tiJy/0VfgqcWgoNzXlrzMhsnPp2RSHctBK/mhGJqBh4a
// SIG // m5L0hipV/aMmtQadwWqk17tKKCyokRU07fAeE2VgLZn1
// SIG // kFtTVMeWI80T86Df51nJEBd6wNpVf8Yu0PwZ9U4x6tPO
// SIG // nDHmGLDxumKik6EF07Ll9JC9j+x9qEs6+hEQZtvO37N1
// SIG // 1OeJfLi01NEw96gZtndSZwwg3fC3Y9mT/u0l2sVWK4lH
// SIG // siYCswIDAQABo4IBczCCAW8wHwYDVR0lBBgwFgYKKwYB
// SIG // BAGCN0wIAQYIKwYBBQUHAwMwHQYDVR0OBBYEFHYemqRq
// SIG // 6/zTsNJ+DmUnNpbvNxiWMEUGA1UdEQQ+MDykOjA4MR4w
// SIG // HAYDVQQLExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xFjAU
// SIG // BgNVBAUTDTQ2NDIyMys0NzIyMzYwHwYDVR0jBBgwFoAU
// SIG // SG5k5VAF04KqFzc3IrVtqMp1ApUwVAYDVR0fBE0wSzBJ
// SIG // oEegRYZDaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
// SIG // aW9wcy9jcmwvTWljQ29kU2lnUENBMjAxMV8yMDExLTA3
// SIG // LTA4LmNybDBhBggrBgEFBQcBAQRVMFMwUQYIKwYBBQUH
// SIG // MAKGRWh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lv
// SIG // cHMvY2VydHMvTWljQ29kU2lnUENBMjAxMV8yMDExLTA3
// SIG // LTA4LmNydDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3DQEB
// SIG // DAUAA4ICAQBWHX7gj/4B8GaQkHtPZBeCGJ8H6khiyj9r
// SIG // WCActkLMWVXfi1vnmcGTv9qYQxzmKLeE+c/pKcxFHCmf
// SIG // z3gnR8tQtzHBRvDILStRtGJfc/UFRysvP+CJZKBqqyhP
// SIG // w9J+2nrCe3r+womL1MlJUGnzrHIciPvLg7NHPXLmrekN
// SIG // m1GXURpiiGbVrpv5XbTE5L/o/u2hA8UheFhD9v12oZoY
// SIG // DxZgBIk0E+eYhv0QbblykcpwqANQHZoVM5RAZDpLwLKg
// SIG // LJ8TYjKvBiPaLZS3mN8W6GyBW5BjR6WFLGFmzPi1hkxh
// SIG // urwSKShhEb4y+BxER5NYq4b2IEXH8Bbs7nRos3peHdOQ
// SIG // ZYt+cY5LAITnrgKCl1pfcm9f/a99ap9mF8gNqKXa35IM
// SIG // yRY43Ic29BLK+kHw/WAVlGvaWRoV7gY1ThcLX70Xo9W3
// SIG // Poa/pSKePmHG7qYr5mkb8A1QjEyCPiXHILGnjN5anpxP
// SIG // ieLUp2bUu35T6qT2jZf3eG3ULpJfqtgvJHLdpghmzuoq
// SIG // SpLRgCj5RGJIGMjZ68mSwJJ0/wtuhsYs/xJnbqkHhSp5
// SIG // jQkb1t1tm8BU29E35iOOhDWcv2rXynVqgimthyytYk9R
// SIG // ZBmMHrMxr/vRjU2ZfK/3Ru0L0VDnmWO4Wnx9AoJv+R/c
// SIG // avpQWxjNn+C1qDD6gDUJNK/97Ie7Lte3ZjCCB3owggVi
// SIG // oAMCAQICCmEOkNIAAAAAAAMwDQYJKoZIhvcNAQELBQAw
// SIG // gYgxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5n
// SIG // dG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVN
// SIG // aWNyb3NvZnQgQ29ycG9yYXRpb24xMjAwBgNVBAMTKU1p
// SIG // Y3Jvc29mdCBSb290IENlcnRpZmljYXRlIEF1dGhvcml0
// SIG // eSAyMDExMB4XDTExMDcwODIwNTkwOVoXDTI2MDcwODIx
// SIG // MDkwOVowfjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEoMCYGA1UE
// SIG // AxMfTWljcm9zb2Z0IENvZGUgU2lnbmluZyBQQ0EgMjAx
// SIG // MTCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIB
// SIG // AKvw+nIQHC6t2G6qghBNNLrytlghn0IbKmvpWlCquAY4
// SIG // GgRJun/DDB7dN2vGEtgL8DjCmQawyDnVARQxQtOJDXlk
// SIG // h36UYCRsr55JnOloXtLfm1OyCizDr9mpK656Ca/XllnK
// SIG // YBoF6WZ26DJSJhIv56sIUM+zRLdd2MQuA3WraPPLbfM6
// SIG // XKEW9Ea64DhkrG5kNXimoGMPLdNAk/jj3gcN1Vx5pUkp
// SIG // 5w2+oBN3vpQ97/vjK1oQH01WKKJ6cuASOrdJXtjt7UOR
// SIG // g9l7snuGG9k+sYxd6IlPhBryoS9Z5JA7La4zWMW3Pv4y
// SIG // 07MDPbGyr5I4ftKdgCz1TlaRITUlwzluZH9TupwPrRkj
// SIG // hMv0ugOGjfdf8NBSv4yUh7zAIXQlXxgotswnKDglmDlK
// SIG // Ns98sZKuHCOnqWbsYR9q4ShJnV+I4iVd0yFLPlLEtVc/
// SIG // JAPw0XpbL9Uj43BdD1FGd7P4AOG8rAKCX9vAFbO9G9RV
// SIG // S+c5oQ/pI0m8GLhEfEXkwcNyeuBy5yTfv0aZxe/CHFfb
// SIG // g43sTUkwp6uO3+xbn6/83bBm4sGXgXvt1u1L50kppxMo
// SIG // pqd9Z4DmimJ4X7IvhNdXnFy/dygo8e1twyiPLI9AN0/B
// SIG // 4YVEicQJTMXUpUMvdJX3bvh4IFgsE11glZo+TzOE2rCI
// SIG // F96eTvSWsLxGoGyY0uDWiIwLAgMBAAGjggHtMIIB6TAQ
// SIG // BgkrBgEEAYI3FQEEAwIBADAdBgNVHQ4EFgQUSG5k5VAF
// SIG // 04KqFzc3IrVtqMp1ApUwGQYJKwYBBAGCNxQCBAweCgBT
// SIG // AHUAYgBDAEEwCwYDVR0PBAQDAgGGMA8GA1UdEwEB/wQF
// SIG // MAMBAf8wHwYDVR0jBBgwFoAUci06AjGQQ7kUBU7h6qfH
// SIG // MdEjiTQwWgYDVR0fBFMwUTBPoE2gS4ZJaHR0cDovL2Ny
// SIG // bC5taWNyb3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMv
// SIG // TWljUm9vQ2VyQXV0MjAxMV8yMDExXzAzXzIyLmNybDBe
// SIG // BggrBgEFBQcBAQRSMFAwTgYIKwYBBQUHMAKGQmh0dHA6
// SIG // Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2VydHMvTWlj
// SIG // Um9vQ2VyQXV0MjAxMV8yMDExXzAzXzIyLmNydDCBnwYD
// SIG // VR0gBIGXMIGUMIGRBgkrBgEEAYI3LgMwgYMwPwYIKwYB
// SIG // BQUHAgEWM2h0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9w
// SIG // a2lvcHMvZG9jcy9wcmltYXJ5Y3BzLmh0bTBABggrBgEF
// SIG // BQcCAjA0HjIgHQBMAGUAZwBhAGwAXwBwAG8AbABpAGMA
// SIG // eQBfAHMAdABhAHQAZQBtAGUAbgB0AC4gHTANBgkqhkiG
// SIG // 9w0BAQsFAAOCAgEAZ/KGpZjgVHkaLtPYdGcimwuWEeFj
// SIG // kplCln3SeQyQwWVfLiw++MNy0W2D/r4/6ArKO79HqaPz
// SIG // adtjvyI1pZddZYSQfYtGUFXYDJJ80hpLHPM8QotS0LD9
// SIG // a+M+By4pm+Y9G6XUtR13lDni6WTJRD14eiPzE32mkHSD
// SIG // jfTLJgJGKsKKELukqQUMm+1o+mgulaAqPyprWEljHwlp
// SIG // blqYluSD9MCP80Yr3vw70L01724lruWvJ+3Q3fMOr5ko
// SIG // l5hNDj0L8giJ1h/DMhji8MUtzluetEk5CsYKwsatruWy
// SIG // 2dsViFFFWDgycScaf7H0J/jeLDogaZiyWYlobm+nt3TD
// SIG // QAUGpgEqKD6CPxNNZgvAs0314Y9/HG8VfUWnduVAKmWj
// SIG // w11SYobDHWM2l4bf2vP48hahmifhzaWX0O5dY0HjWwec
// SIG // hz4GdwbRBrF1HxS+YWG18NzGGwS+30HHDiju3mUv7Jf2
// SIG // oVyW2ADWoUa9WfOXpQlLSBCZgB/QACnFsZulP0V3HjXG
// SIG // 0qKin3p6IvpIlR+r+0cjgPWe+L9rt0uX4ut1eBrs6jeZ
// SIG // eRhL/9azI2h15q/6/IvrC4DqaTuv/DDtBEyO3991bWOR
// SIG // PdGdVk5Pv4BXIqF4ETIheu9BCrE/+6jMpF3BoYibV3FW
// SIG // TkhFwELJm3ZbCoBIa/15n8G9bW1qyVJzEw16UM0xghof
// SIG // MIIaGwIBATCBlTB+MQswCQYDVQQGEwJVUzETMBEGA1UE
// SIG // CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
// SIG // MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgw
// SIG // JgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBD
// SIG // QSAyMDExAhMzAAADBMEDGX7GBeQEAAAAAAMEMA0GCWCG
// SIG // SAFlAwQCAQUAoIGuMBkGCSqGSIb3DQEJAzEMBgorBgEE
// SIG // AYI3AgEEMBwGCisGAQQBgjcCAQsxDjAMBgorBgEEAYI3
// SIG // AgEVMC8GCSqGSIb3DQEJBDEiBCD3omjKU+2ltBtHmjuF
// SIG // e7vjmLFCFgQ9lehLg9Wo3349uDBCBgorBgEEAYI3AgEM
// SIG // MTQwMqAUgBIATQBpAGMAcgBvAHMAbwBmAHShGoAYaHR0
// SIG // cDovL3d3dy5taWNyb3NvZnQuY29tMA0GCSqGSIb3DQEB
// SIG // AQUABIIBgCT0R2IkihB3BAxTxsy6v5/As93NvlBouEXZ
// SIG // oX+WlYxDOYBxYvgcNiFLwheXvGnug05nxeuKKR15RwLW
// SIG // qzUyKaVW0JEuaPtIWowtJbKa+Ht2wSbdGKa+z8OVTesJ
// SIG // 5Jb83n9teI+wObuV/6xJXXhw/sm5qaXoDhjIVzTZJdWl
// SIG // vxgzAyc0X7supv2EgIcvC6i1PZO/+tAgNMxQu0YPZQFL
// SIG // 4jduvYHBlVm0JN+tZTgbi4U4EZSCPZpHj1J70JNosioq
// SIG // +0K50N8D6PgqtgDhQTU6BzenbLo3z0F+p9Y1TQv4WE0X
// SIG // zeSTSqphF2BdPUbInoMCXMEgLjurjcQvgFrSG+U7nBZQ
// SIG // ZJZ+GtPHfPoXXv1w0YBOaN6WIo8F10ZEsjFRUDwz1Lbk
// SIG // f47J2qciZdg6W/vfZ6pzCh2eSlx33S8n31pr/q+11E8n
// SIG // LaciacneskhqRsak8qwMJIYmckeeAVTZmsUIr8hQ9Uza
// SIG // 1X4Kp9QJ+xPVk61qoPzjDrP8CVdcrozxATBp6qGCFykw
// SIG // ghclBgorBgEEAYI3AwMBMYIXFTCCFxEGCSqGSIb3DQEH
// SIG // AqCCFwIwghb+AgEDMQ8wDQYJYIZIAWUDBAIBBQAwggFZ
// SIG // BgsqhkiG9w0BCRABBKCCAUgEggFEMIIBQAIBAQYKKwYB
// SIG // BAGEWQoDATAxMA0GCWCGSAFlAwQCAQUABCB3VN79WCOr
// SIG // E7lGOD8dDeUkJG2rjUcrvH+/DLPv+hBw9wIGZBsSAml2
// SIG // GBMyMDIzMDMyODA0MDQxNi45MjZaMASAAgH0oIHYpIHV
// SIG // MIHSMQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGlu
// SIG // Z3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMV
// SIG // TWljcm9zb2Z0IENvcnBvcmF0aW9uMS0wKwYDVQQLEyRN
// SIG // aWNyb3NvZnQgSXJlbGFuZCBPcGVyYXRpb25zIExpbWl0
// SIG // ZWQxJjAkBgNVBAsTHVRoYWxlcyBUU1MgRVNOOjE3OUUt
// SIG // NEJCMC04MjQ2MSUwIwYDVQQDExxNaWNyb3NvZnQgVGlt
// SIG // ZS1TdGFtcCBTZXJ2aWNloIIReDCCBycwggUPoAMCAQIC
// SIG // EzMAAAG1rRrf14VwbRMAAQAAAbUwDQYJKoZIhvcNAQEL
// SIG // BQAwfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
// SIG // bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoT
// SIG // FU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMd
// SIG // TWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAwHhcN
// SIG // MjIwOTIwMjAyMjExWhcNMjMxMjE0MjAyMjExWjCB0jEL
// SIG // MAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24x
// SIG // EDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jv
// SIG // c29mdCBDb3Jwb3JhdGlvbjEtMCsGA1UECxMkTWljcm9z
// SIG // b2Z0IElyZWxhbmQgT3BlcmF0aW9ucyBMaW1pdGVkMSYw
// SIG // JAYDVQQLEx1UaGFsZXMgVFNTIEVTTjoxNzlFLTRCQjAt
// SIG // ODI0NjElMCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUtU3Rh
// SIG // bXAgU2VydmljZTCCAiIwDQYJKoZIhvcNAQEBBQADggIP
// SIG // ADCCAgoCggIBAJcLCrhlXoLCjYmFxcFPgkh57dmuz31s
// SIG // Nsj8IlvmEZRCbB94mxSIj35P8m5TKfCRmp7bvuw4v/t3
// SIG // ucFjf52yVCDFIxFiZ3PCTI6D5hwlrDLSTrkf9UbuGmtU
// SIG // a8ULSHpatPfEwZeJOzbBBPO5e6ihZsvIsBjUI5MK9GzL
// SIG // uAScMuwVF4lx3oDklPfdq30OMTWaMc57+Nky0LHPTZnA
// SIG // auVrJZKlQE3HPD0n4ASxKXRtQ6dsKjcOCayRcCTQNW38
// SIG // 00nGAAXObJkWQYLD+CYiv/Ala5aHIXhMkKJ45t6xbba6
// SIG // IwK3klJ4sQC7vaQ67ASOA1Dxht+KCG4niNaKhZf8ZOwP
// SIG // u7jPJOKPInzFVjU2nM2z5XQ2LZ+oQa3u69uURA+LnnAs
// SIG // T/A8ct+GD1BJVpZTz9ywF6eXDMEY8fhFs4xLSCxCl7gH
// SIG // H8a1wk8MmIZuVzcwgmWIeP4BdlNsv22H3pCqWqBWMJKG
// SIG // Xk+mcaEG1+Sn7YI/rWZBVdtVL2SJCem9+Gv+OHba7Cun
// SIG // Yk5lZzUzPSej+hIZZNrH3FMGxyBi/JmKnSjosneEcTgp
// SIG // kr3BTZGRIK5OePJhwmw208jvcUszdRJFsW6fJ/yx1Z2f
// SIG // X6eYSCxp7ZDM2g+Wl0QkMh0iIbD7Ue0P6yqB8oxaoLRj
// SIG // vX7Z8WL8cza2ynjAs8JnKsDK1+h3MXtEnimfAgMBAAGj
// SIG // ggFJMIIBRTAdBgNVHQ4EFgQUbFCG2YKGVV1V1VkF9DpN
// SIG // VTtmx1MwHwYDVR0jBBgwFoAUn6cVXQBeYl2D9OXSZacb
// SIG // UzUZ6XIwXwYDVR0fBFgwVjBUoFKgUIZOaHR0cDovL3d3
// SIG // dy5taWNyb3NvZnQuY29tL3BraW9wcy9jcmwvTWljcm9z
// SIG // b2Z0JTIwVGltZS1TdGFtcCUyMFBDQSUyMDIwMTAoMSku
// SIG // Y3JsMGwGCCsGAQUFBwEBBGAwXjBcBggrBgEFBQcwAoZQ
// SIG // aHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9j
// SIG // ZXJ0cy9NaWNyb3NvZnQlMjBUaW1lLVN0YW1wJTIwUENB
// SIG // JTIwMjAxMCgxKS5jcnQwDAYDVR0TAQH/BAIwADAWBgNV
// SIG // HSUBAf8EDDAKBggrBgEFBQcDCDAOBgNVHQ8BAf8EBAMC
// SIG // B4AwDQYJKoZIhvcNAQELBQADggIBAJBRjqcoyldrNrAP
// SIG // sE6g8A3YadJhaz7YlOKzdzqJ01qm/OTOlh9fXPz+de8b
// SIG // oywoofx5ZT+cSlpl5wCEVdfzUA5CQS0nS02/zULXE9RV
// SIG // hkOwjE565/bS2caiBbSlcpb0Dcod9Qv6pAvEJjacs2pD
// SIG // tBt/LjhoDpCfRKuJwPu0MFX6Gw5YIFrhKc3RZ0Xcly99
// SIG // oDqkr6y4xSqb+ChFamgU4msQlmQ5SIRt2IFM2u3JxuWd
// SIG // kgP33jKvyIldOgM1GnWcOl4HE66l5hJhNLTJnZeODDBQ
// SIG // t8BlPQFXhQlinQ/Vjp2ANsx4Plxdi0FbaNFWLRS3enOg
// SIG // 0BXJgd/BrzwilWEp/K9dBKF7kTfoEO4S3IptdnrDp1uB
// SIG // eGxwph1k1VngBoD4kiLRx0XxiixFGZqLVTnRT0fMIrgA
// SIG // 0/3x0lwZJHaS9drb4BBhC3k858xbpWdem/zb+nbW4EkW
// SIG // a3nrCQTSqU43WI7vxqp5QJKX5S+idMMZPee/1FWJ5o40
// SIG // WOtY1/dEBkJgc5vb7P/tm49Nl8f2118vL6ue45jV0Nrn
// SIG // zmiZt5wHA9qjmkslxDo/ZqoTLeLXbzIx4YjT5XX49EOy
// SIG // qtR4HUQaylpMwkDYuLbPB0SQYqTWlaVn1OwXEZ/AXmM3
// SIG // S6CM8ESw7Wrc+mgYaN6A/21x62WoMaazOTLDAf61X2+V
// SIG // 59WEu/7hMIIHcTCCBVmgAwIBAgITMwAAABXF52ueAptJ
// SIG // mQAAAAAAFTANBgkqhkiG9w0BAQsFADCBiDELMAkGA1UE
// SIG // BhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNV
// SIG // BAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBD
// SIG // b3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWljcm9zb2Z0IFJv
// SIG // b3QgQ2VydGlmaWNhdGUgQXV0aG9yaXR5IDIwMTAwHhcN
// SIG // MjEwOTMwMTgyMjI1WhcNMzAwOTMwMTgzMjI1WjB8MQsw
// SIG // CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQ
// SIG // MA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9z
// SIG // b2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3Nv
// SIG // ZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDCCAiIwDQYJKoZI
// SIG // hvcNAQEBBQADggIPADCCAgoCggIBAOThpkzntHIhC3mi
// SIG // y9ckeb0O1YLT/e6cBwfSqWxOdcjKNVf2AX9sSuDivbk+
// SIG // F2Az/1xPx2b3lVNxWuJ+Slr+uDZnhUYjDLWNE893MsAQ
// SIG // GOhgfWpSg0S3po5GawcU88V29YZQ3MFEyHFcUTE3oAo4
// SIG // bo3t1w/YJlN8OWECesSq/XJprx2rrPY2vjUmZNqYO7oa
// SIG // ezOtgFt+jBAcnVL+tuhiJdxqD89d9P6OU8/W7IVWTe/d
// SIG // vI2k45GPsjksUZzpcGkNyjYtcI4xyDUoveO0hyTD4MmP
// SIG // frVUj9z6BVWYbWg7mka97aSueik3rMvrg0XnRm7KMtXA
// SIG // hjBcTyziYrLNueKNiOSWrAFKu75xqRdbZ2De+JKRHh09
// SIG // /SDPc31BmkZ1zcRfNN0Sidb9pSB9fvzZnkXftnIv231f
// SIG // gLrbqn427DZM9ituqBJR6L8FA6PRc6ZNN3SUHDSCD/AQ
// SIG // 8rdHGO2n6Jl8P0zbr17C89XYcz1DTsEzOUyOArxCaC4Q
// SIG // 6oRRRuLRvWoYWmEBc8pnol7XKHYC4jMYctenIPDC+hIK
// SIG // 12NvDMk2ZItboKaDIV1fMHSRlJTYuVD5C4lh8zYGNRiE
// SIG // R9vcG9H9stQcxWv2XFJRXRLbJbqvUAV6bMURHXLvjflS
// SIG // xIUXk8A8FdsaN8cIFRg/eKtFtvUeh17aj54WcmnGrnu3
// SIG // tz5q4i6tAgMBAAGjggHdMIIB2TASBgkrBgEEAYI3FQEE
// SIG // BQIDAQABMCMGCSsGAQQBgjcVAgQWBBQqp1L+ZMSavoKR
// SIG // PEY1Kc8Q/y8E7jAdBgNVHQ4EFgQUn6cVXQBeYl2D9OXS
// SIG // ZacbUzUZ6XIwXAYDVR0gBFUwUzBRBgwrBgEEAYI3TIN9
// SIG // AQEwQTA/BggrBgEFBQcCARYzaHR0cDovL3d3dy5taWNy
// SIG // b3NvZnQuY29tL3BraW9wcy9Eb2NzL1JlcG9zaXRvcnku
// SIG // aHRtMBMGA1UdJQQMMAoGCCsGAQUFBwMIMBkGCSsGAQQB
// SIG // gjcUAgQMHgoAUwB1AGIAQwBBMAsGA1UdDwQEAwIBhjAP
// SIG // BgNVHRMBAf8EBTADAQH/MB8GA1UdIwQYMBaAFNX2VsuP
// SIG // 6KJcYmjRPZSQW9fOmhjEMFYGA1UdHwRPME0wS6BJoEeG
// SIG // RWh0dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3Js
// SIG // L3Byb2R1Y3RzL01pY1Jvb0NlckF1dF8yMDEwLTA2LTIz
// SIG // LmNybDBaBggrBgEFBQcBAQROMEwwSgYIKwYBBQUHMAKG
// SIG // Pmh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2Vy
// SIG // dHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYtMjMuY3J0MA0G
// SIG // CSqGSIb3DQEBCwUAA4ICAQCdVX38Kq3hLB9nATEkW+Ge
// SIG // ckv8qW/qXBS2Pk5HZHixBpOXPTEztTnXwnE2P9pkbHzQ
// SIG // dTltuw8x5MKP+2zRoZQYIu7pZmc6U03dmLq2HnjYNi6c
// SIG // qYJWAAOwBb6J6Gngugnue99qb74py27YP0h1AdkY3m2C
// SIG // DPVtI1TkeFN1JFe53Z/zjj3G82jfZfakVqr3lbYoVSfQ
// SIG // JL1AoL8ZthISEV09J+BAljis9/kpicO8F7BUhUKz/Aye
// SIG // ixmJ5/ALaoHCgRlCGVJ1ijbCHcNhcy4sa3tuPywJeBTp
// SIG // kbKpW99Jo3QMvOyRgNI95ko+ZjtPu4b6MhrZlvSP9pEB
// SIG // 9s7GdP32THJvEKt1MMU0sHrYUP4KWN1APMdUbZ1jdEgs
// SIG // sU5HLcEUBHG/ZPkkvnNtyo4JvbMBV0lUZNlz138eW0QB
// SIG // jloZkWsNn6Qo3GcZKCS6OEuabvshVGtqRRFHqfG3rsjo
// SIG // iV5PndLQTHa1V1QJsWkBRH58oWFsc/4Ku+xBZj1p/cvB
// SIG // QUl+fpO+y/g75LcVv7TOPqUxUYS8vwLBgqJ7Fx0ViY1w
// SIG // /ue10CgaiQuPNtq6TPmb/wrpNPgkNWcr4A245oyZ1uEi
// SIG // 6vAnQj0llOZ0dFtq0Z4+7X6gMTN9vMvpe784cETRkPHI
// SIG // qzqKOghif9lwY1NNje6CbaUFEMFxBmoQtB1VM1izoXBm
// SIG // 8qGCAtQwggI9AgEBMIIBAKGB2KSB1TCB0jELMAkGA1UE
// SIG // BhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNV
// SIG // BAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBD
// SIG // b3Jwb3JhdGlvbjEtMCsGA1UECxMkTWljcm9zb2Z0IEly
// SIG // ZWxhbmQgT3BlcmF0aW9ucyBMaW1pdGVkMSYwJAYDVQQL
// SIG // Ex1UaGFsZXMgVFNTIEVTTjoxNzlFLTRCQjAtODI0NjEl
// SIG // MCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUtU3RhbXAgU2Vy
// SIG // dmljZaIjCgEBMAcGBSsOAwIaAxUAjTCfa9dUWY9D1rt7
// SIG // pPmkBxdyLFWggYMwgYCkfjB8MQswCQYDVQQGEwJVUzET
// SIG // MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
// SIG // bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
// SIG // aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFt
// SIG // cCBQQ0EgMjAxMDANBgkqhkiG9w0BAQUFAAIFAOfMz/Iw
// SIG // IhgPMjAyMzAzMjgxMDMxMTRaGA8yMDIzMDMyOTEwMzEx
// SIG // NFowdDA6BgorBgEEAYRZCgQBMSwwKjAKAgUA58zP8gIB
// SIG // ADAHAgEAAgIBqDAHAgEAAgISZDAKAgUA584hcgIBADA2
// SIG // BgorBgEEAYRZCgQCMSgwJjAMBgorBgEEAYRZCgMCoAow
// SIG // CAIBAAIDB6EgoQowCAIBAAIDAYagMA0GCSqGSIb3DQEB
// SIG // BQUAA4GBADCMWNCxMR9jfQxWxztzf8m8qgz4eworuL3k
// SIG // h73q0dJBLVE48VcPLS6VTRxQ3/ccaP3UQmcVZsspZeM7
// SIG // dEGPHYLVPoDPbqxzGOMqI9FWntK7zT69cDc5iabinZEh
// SIG // ySJJZ9eeqYRUHggCQbpPUQn3K+/K7CFQLouESxqOLjZT
// SIG // mabgMYIEDTCCBAkCAQEwgZMwfDELMAkGA1UEBhMCVVMx
// SIG // EzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1Jl
// SIG // ZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3Jh
// SIG // dGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3Rh
// SIG // bXAgUENBIDIwMTACEzMAAAG1rRrf14VwbRMAAQAAAbUw
// SIG // DQYJYIZIAWUDBAIBBQCgggFKMBoGCSqGSIb3DQEJAzEN
// SIG // BgsqhkiG9w0BCRABBDAvBgkqhkiG9w0BCQQxIgQgMsGn
// SIG // xfkY4ukoarOHgESHWrIPYTj95AOBan+9oP9d9XEwgfoG
// SIG // CyqGSIb3DQEJEAIvMYHqMIHnMIHkMIG9BCAnyg01LWhn
// SIG // Fon2HNzlZyKae2JJ9EvCXJVc65QIBfHIgzCBmDCBgKR+
// SIG // MHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5n
// SIG // dG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVN
// SIG // aWNyb3NvZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMTHU1p
// SIG // Y3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEwAhMzAAAB
// SIG // ta0a39eFcG0TAAEAAAG1MCIEIORVIo4+ya+1Sf6gvWtc
// SIG // hclJPTlpZRMHFJh73Iqu1pc4MA0GCSqGSIb3DQEBCwUA
// SIG // BIICAA0CpvgArmEhSexLdE3YuA5dbHO+DnWeB5nNXUC+
// SIG // xqQ5DPqbXfNqYtwry31wCZxDIlKuRabCazV/N0szeUso
// SIG // 0Qq+saKfevAGD5J6f9H0OPQzFdadQQPYKXYEuRUDosTk
// SIG // h8vKgqGmTRmBO54S59ldIhvAuTmIr85tuvi6Rjrxm9lY
// SIG // GoFkXW6iD2BWemf1iDr7u0a0uSFn++vXC1Q067Bya7mD
// SIG // NUGMVJlRVAneAMOOiW8dWPhHAuSVRBdDivrPadoxFJxe
// SIG // BhJDmy5g4orGF1v4r/lF2wXyE+3ljlTPDxAS+Jr6rruc
// SIG // cjH90ulfoaqN/zQZEyL85385xVm1y+yCVrST4jT2XFE6
// SIG // RiG39hDaEooCsZJ3Th7LKHtfWL6bFiWNwlpRB/VV/4jr
// SIG // kQ2w9F3fp+9OBFBJ0ajUTkOw4CdqjEH8rtUNFx21M/E7
// SIG // uCas/JfiPq5CvWW5YEAXV9puIS1GqYKo3NaBwoZ2KMP9
// SIG // 2azrNFsTXeJGVoz2oJ2p8g/9cAxwCv2lNuxMossm3qFk
// SIG // 2TVyubyIuzse4xlxcKw1TmkeXEo+zXtPGlTjHmV3aBf1
// SIG // phbY/2am0cF5bxAmicsUjEc8ujxEQZgBVb1HFjRVhxE7
// SIG // POwUczmclGJR4aglRXCtXVAgQl9mFJUac3Hi1f1T3ipC
// SIG // loZczbDJWSM9LrzV66OSUdZT4tV5
// SIG // End signature block
