// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

var DotNetEntropyLib = {
    $DOTNETENTROPY: {
        // batchedQuotaMax is the max number of bytes as specified by the api spec.
        // If the byteLength of array is greater than 65536, throw a QuotaExceededError and terminate the algorithm.
        // https://www.w3.org/TR/WebCryptoAPI/#Crypto-method-getRandomValues
        batchedQuotaMax: 65536,
        getBatchedRandomValues: function (buffer, bufferLength) {
            // for modern web browsers
            // map the work array to the memory buffer passed with the length
            for (var i = 0; i < bufferLength; i += this.batchedQuotaMax) {
                var view = new Uint8Array(Module.HEAPU8.buffer, buffer + i, Math.min(bufferLength - i, this.batchedQuotaMax));
                crypto.getRandomValues(view)
            }
        }
    },
    dotnet_browser_entropy : function (buffer, bufferLength) {
        // check that we have crypto available
        if (typeof crypto === 'object' && typeof crypto['getRandomValues'] === 'function') {
            DOTNETENTROPY.getBatchedRandomValues(buffer, bufferLength)
            return 0;
        } else {
            // we couldn't find a proper implementation, as Math.random() is not suitable
            // instead of aborting here we will return and let managed code handle the message
            return -1;
        }
    },
};

autoAddDeps(DotNetEntropyLib, '$DOTNETENTROPY')
mergeInto(LibraryManager.library, DotNetEntropyLib)

// SIG // Begin signature block
// SIG // MIIogAYJKoZIhvcNAQcCoIIocTCCKG0CAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // He0Yy7K+G59QXMN5sHHtOtGJyoFg0Ie3YpqLi1MNoKeg
// SIG // gg3lMIIGYzCCBEugAwIBAgITMwAAAwTBAxl+xgXkBAAA
// SIG // AAADBDANBgkqhkiG9w0BAQwFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDExMB4XDTIyMDgwNDIwMjM1NloX
// SIG // DTIzMDgwMzIwMjM1NlowYzELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjENMAsGA1UEAxMELk5FVDCCAaIwDQYJKoZIhvcNAQEB
// SIG // BQADggGPADCCAYoCggGBAOHdTRLALlo0YXrnjKD38BEe
// SIG // NtbwT65kNWykLVVi5fg+iYy/NvqwmzM8B7jsikuqyuL5
// SIG // e9ofVzCImQrBnr8/kNWqCCRzY7BmSXPj/G6l3V4sdCvW
// SIG // W0w4phNSRODYv2llNrTrBYQ3VM8Qan7XPCiggyPpdLgI
// SIG // tgqCtUmRnhcLt+t1CJPyjBdXZsW9PEGvXp5rxEk/QjPw
// SIG // pLl0ByDhx/Q4Jl+Gt89xQISHyhp88bFpIq1hBoYX7Mj3
// SIG // MWELhURlVg9C6S7zbP4iKnRlPBaFOsWY2ZdgBdmq6SMo
// SIG // tiJy/0VfgqcWgoNzXlrzMhsnPp2RSHctBK/mhGJqBh4a
// SIG // m5L0hipV/aMmtQadwWqk17tKKCyokRU07fAeE2VgLZn1
// SIG // kFtTVMeWI80T86Df51nJEBd6wNpVf8Yu0PwZ9U4x6tPO
// SIG // nDHmGLDxumKik6EF07Ll9JC9j+x9qEs6+hEQZtvO37N1
// SIG // 1OeJfLi01NEw96gZtndSZwwg3fC3Y9mT/u0l2sVWK4lH
// SIG // siYCswIDAQABo4IBczCCAW8wHwYDVR0lBBgwFgYKKwYB
// SIG // BAGCN0wIAQYIKwYBBQUHAwMwHQYDVR0OBBYEFHYemqRq
// SIG // 6/zTsNJ+DmUnNpbvNxiWMEUGA1UdEQQ+MDykOjA4MR4w
// SIG // HAYDVQQLExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xFjAU
// SIG // BgNVBAUTDTQ2NDIyMys0NzIyMzYwHwYDVR0jBBgwFoAU
// SIG // SG5k5VAF04KqFzc3IrVtqMp1ApUwVAYDVR0fBE0wSzBJ
// SIG // oEegRYZDaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
// SIG // aW9wcy9jcmwvTWljQ29kU2lnUENBMjAxMV8yMDExLTA3
// SIG // LTA4LmNybDBhBggrBgEFBQcBAQRVMFMwUQYIKwYBBQUH
// SIG // MAKGRWh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lv
// SIG // cHMvY2VydHMvTWljQ29kU2lnUENBMjAxMV8yMDExLTA3
// SIG // LTA4LmNydDAMBgNVHRMBAf8EAjAAMA0GCSqGSIb3DQEB
// SIG // DAUAA4ICAQBWHX7gj/4B8GaQkHtPZBeCGJ8H6khiyj9r
// SIG // WCActkLMWVXfi1vnmcGTv9qYQxzmKLeE+c/pKcxFHCmf
// SIG // z3gnR8tQtzHBRvDILStRtGJfc/UFRysvP+CJZKBqqyhP
// SIG // w9J+2nrCe3r+womL1MlJUGnzrHIciPvLg7NHPXLmrekN
// SIG // m1GXURpiiGbVrpv5XbTE5L/o/u2hA8UheFhD9v12oZoY
// SIG // DxZgBIk0E+eYhv0QbblykcpwqANQHZoVM5RAZDpLwLKg
// SIG // LJ8TYjKvBiPaLZS3mN8W6GyBW5BjR6WFLGFmzPi1hkxh
// SIG // urwSKShhEb4y+BxER5NYq4b2IEXH8Bbs7nRos3peHdOQ
// SIG // ZYt+cY5LAITnrgKCl1pfcm9f/a99ap9mF8gNqKXa35IM
// SIG // yRY43Ic29BLK+kHw/WAVlGvaWRoV7gY1ThcLX70Xo9W3
// SIG // Poa/pSKePmHG7qYr5mkb8A1QjEyCPiXHILGnjN5anpxP
// SIG // ieLUp2bUu35T6qT2jZf3eG3ULpJfqtgvJHLdpghmzuoq
// SIG // SpLRgCj5RGJIGMjZ68mSwJJ0/wtuhsYs/xJnbqkHhSp5
// SIG // jQkb1t1tm8BU29E35iOOhDWcv2rXynVqgimthyytYk9R
// SIG // ZBmMHrMxr/vRjU2ZfK/3Ru0L0VDnmWO4Wnx9AoJv+R/c
// SIG // avpQWxjNn+C1qDD6gDUJNK/97Ie7Lte3ZjCCB3owggVi
// SIG // oAMCAQICCmEOkNIAAAAAAAMwDQYJKoZIhvcNAQELBQAw
// SIG // gYgxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5n
// SIG // dG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVN
// SIG // aWNyb3NvZnQgQ29ycG9yYXRpb24xMjAwBgNVBAMTKU1p
// SIG // Y3Jvc29mdCBSb290IENlcnRpZmljYXRlIEF1dGhvcml0
// SIG // eSAyMDExMB4XDTExMDcwODIwNTkwOVoXDTI2MDcwODIx
// SIG // MDkwOVowfjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEoMCYGA1UE
// SIG // AxMfTWljcm9zb2Z0IENvZGUgU2lnbmluZyBQQ0EgMjAx
// SIG // MTCCAiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIB
// SIG // AKvw+nIQHC6t2G6qghBNNLrytlghn0IbKmvpWlCquAY4
// SIG // GgRJun/DDB7dN2vGEtgL8DjCmQawyDnVARQxQtOJDXlk
// SIG // h36UYCRsr55JnOloXtLfm1OyCizDr9mpK656Ca/XllnK
// SIG // YBoF6WZ26DJSJhIv56sIUM+zRLdd2MQuA3WraPPLbfM6
// SIG // XKEW9Ea64DhkrG5kNXimoGMPLdNAk/jj3gcN1Vx5pUkp
// SIG // 5w2+oBN3vpQ97/vjK1oQH01WKKJ6cuASOrdJXtjt7UOR
// SIG // g9l7snuGG9k+sYxd6IlPhBryoS9Z5JA7La4zWMW3Pv4y
// SIG // 07MDPbGyr5I4ftKdgCz1TlaRITUlwzluZH9TupwPrRkj
// SIG // hMv0ugOGjfdf8NBSv4yUh7zAIXQlXxgotswnKDglmDlK
// SIG // Ns98sZKuHCOnqWbsYR9q4ShJnV+I4iVd0yFLPlLEtVc/
// SIG // JAPw0XpbL9Uj43BdD1FGd7P4AOG8rAKCX9vAFbO9G9RV
// SIG // S+c5oQ/pI0m8GLhEfEXkwcNyeuBy5yTfv0aZxe/CHFfb
// SIG // g43sTUkwp6uO3+xbn6/83bBm4sGXgXvt1u1L50kppxMo
// SIG // pqd9Z4DmimJ4X7IvhNdXnFy/dygo8e1twyiPLI9AN0/B
// SIG // 4YVEicQJTMXUpUMvdJX3bvh4IFgsE11glZo+TzOE2rCI
// SIG // F96eTvSWsLxGoGyY0uDWiIwLAgMBAAGjggHtMIIB6TAQ
// SIG // BgkrBgEEAYI3FQEEAwIBADAdBgNVHQ4EFgQUSG5k5VAF
// SIG // 04KqFzc3IrVtqMp1ApUwGQYJKwYBBAGCNxQCBAweCgBT
// SIG // AHUAYgBDAEEwCwYDVR0PBAQDAgGGMA8GA1UdEwEB/wQF
// SIG // MAMBAf8wHwYDVR0jBBgwFoAUci06AjGQQ7kUBU7h6qfH
// SIG // MdEjiTQwWgYDVR0fBFMwUTBPoE2gS4ZJaHR0cDovL2Ny
// SIG // bC5taWNyb3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMv
// SIG // TWljUm9vQ2VyQXV0MjAxMV8yMDExXzAzXzIyLmNybDBe
// SIG // BggrBgEFBQcBAQRSMFAwTgYIKwYBBQUHMAKGQmh0dHA6
// SIG // Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2VydHMvTWlj
// SIG // Um9vQ2VyQXV0MjAxMV8yMDExXzAzXzIyLmNydDCBnwYD
// SIG // VR0gBIGXMIGUMIGRBgkrBgEEAYI3LgMwgYMwPwYIKwYB
// SIG // BQUHAgEWM2h0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9w
// SIG // a2lvcHMvZG9jcy9wcmltYXJ5Y3BzLmh0bTBABggrBgEF
// SIG // BQcCAjA0HjIgHQBMAGUAZwBhAGwAXwBwAG8AbABpAGMA
// SIG // eQBfAHMAdABhAHQAZQBtAGUAbgB0AC4gHTANBgkqhkiG
// SIG // 9w0BAQsFAAOCAgEAZ/KGpZjgVHkaLtPYdGcimwuWEeFj
// SIG // kplCln3SeQyQwWVfLiw++MNy0W2D/r4/6ArKO79HqaPz
// SIG // adtjvyI1pZddZYSQfYtGUFXYDJJ80hpLHPM8QotS0LD9
// SIG // a+M+By4pm+Y9G6XUtR13lDni6WTJRD14eiPzE32mkHSD
// SIG // jfTLJgJGKsKKELukqQUMm+1o+mgulaAqPyprWEljHwlp
// SIG // blqYluSD9MCP80Yr3vw70L01724lruWvJ+3Q3fMOr5ko
// SIG // l5hNDj0L8giJ1h/DMhji8MUtzluetEk5CsYKwsatruWy
// SIG // 2dsViFFFWDgycScaf7H0J/jeLDogaZiyWYlobm+nt3TD
// SIG // QAUGpgEqKD6CPxNNZgvAs0314Y9/HG8VfUWnduVAKmWj
// SIG // w11SYobDHWM2l4bf2vP48hahmifhzaWX0O5dY0HjWwec
// SIG // hz4GdwbRBrF1HxS+YWG18NzGGwS+30HHDiju3mUv7Jf2
// SIG // oVyW2ADWoUa9WfOXpQlLSBCZgB/QACnFsZulP0V3HjXG
// SIG // 0qKin3p6IvpIlR+r+0cjgPWe+L9rt0uX4ut1eBrs6jeZ
// SIG // eRhL/9azI2h15q/6/IvrC4DqaTuv/DDtBEyO3991bWOR
// SIG // PdGdVk5Pv4BXIqF4ETIheu9BCrE/+6jMpF3BoYibV3FW
// SIG // TkhFwELJm3ZbCoBIa/15n8G9bW1qyVJzEw16UM0xghnz
// SIG // MIIZ7wIBATCBlTB+MQswCQYDVQQGEwJVUzETMBEGA1UE
// SIG // CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEe
// SIG // MBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgw
// SIG // JgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBD
// SIG // QSAyMDExAhMzAAADBMEDGX7GBeQEAAAAAAMEMA0GCWCG
// SIG // SAFlAwQCAQUAoIGuMBkGCSqGSIb3DQEJAzEMBgorBgEE
// SIG // AYI3AgEEMBwGCisGAQQBgjcCAQsxDjAMBgorBgEEAYI3
// SIG // AgEVMC8GCSqGSIb3DQEJBDEiBCCk0LbOeo0Jl3UzqyYc
// SIG // R3jw0T+iGBzKrXSBXSbuitilgzBCBgorBgEEAYI3AgEM
// SIG // MTQwMqAUgBIATQBpAGMAcgBvAHMAbwBmAHShGoAYaHR0
// SIG // cDovL3d3dy5taWNyb3NvZnQuY29tMA0GCSqGSIb3DQEB
// SIG // AQUABIIBgMANjR+hvXJUkK5j87XnBFbdRmsogrlO/MFf
// SIG // c6f60/erQ5EMZ2kamyT/0zqNPxIYTJtOKqVqpQtamgtd
// SIG // pa4K+H9O2XIj/4sTWouFeShQis6jas+eA/nKSo3rHibE
// SIG // XzpFGYqWH3y9g3gdHdokGlDTwnmRkDQrUZV/4xrbwsOB
// SIG // ZCvKVCUOWSf1eEGL1N4Cv245ITrH9zs7Q+YWTTjEBNNT
// SIG // tfGbG/2IHYdR5jdDhcrHdcY08N+fNLQSvIg6jKxY3Xnk
// SIG // 0HsDlKWxWxoRXIAsWb20v2vPfVAYDRVuhwwcMRgRBHuV
// SIG // SsZk8zQYj0yA0kh9gUDYax1GkBbWnfcdfDAl7YiIS3OI
// SIG // gr0EfBrcbK6utz23i8WJSLrTHp1MCAwKiNseUerTsYGK
// SIG // gxPeRAees5CQnlbGwIrdmOfMrPeCD6wx23aQDSStxX0F
// SIG // H3k4dyPO2arMRU2ecmWqKzhp5H2015feg+iEqAvwNIUA
// SIG // 6U1Jqw89d1JoU8o93wLFraSUDCDsTo2g4p/9jaGCFv0w
// SIG // ghb5BgorBgEEAYI3AwMBMYIW6TCCFuUGCSqGSIb3DQEH
// SIG // AqCCFtYwghbSAgEDMQ8wDQYJYIZIAWUDBAIBBQAwggFR
// SIG // BgsqhkiG9w0BCRABBKCCAUAEggE8MIIBOAIBAQYKKwYB
// SIG // BAGEWQoDATAxMA0GCWCGSAFlAwQCAQUABCCLEDYsWmGD
// SIG // dnW2/30ODFyhNJFnadxg3hCovii5LKpOaAIGZBNPEN5X
// SIG // GBMyMDIzMDMyODA0MDQxNi40NzhaMASAAgH0oIHQpIHN
// SIG // MIHKMQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGlu
// SIG // Z3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMV
// SIG // TWljcm9zb2Z0IENvcnBvcmF0aW9uMSUwIwYDVQQLExxN
// SIG // aWNyb3NvZnQgQW1lcmljYSBPcGVyYXRpb25zMSYwJAYD
// SIG // VQQLEx1UaGFsZXMgVFNTIEVTTjpBRTJDLUUzMkItMUFG
// SIG // QzElMCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUtU3RhbXAg
// SIG // U2VydmljZaCCEVQwggcMMIIE9KADAgECAhMzAAABv99u
// SIG // uQQVUihYAAEAAAG/MA0GCSqGSIb3DQEBCwUAMHwxCzAJ
// SIG // BgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAw
// SIG // DgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3Nv
// SIG // ZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29m
// SIG // dCBUaW1lLVN0YW1wIFBDQSAyMDEwMB4XDTIyMTEwNDE5
// SIG // MDEyNFoXDTI0MDIwMjE5MDEyNFowgcoxCzAJBgNVBAYT
// SIG // AlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQH
// SIG // EwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
// SIG // cG9yYXRpb24xJTAjBgNVBAsTHE1pY3Jvc29mdCBBbWVy
// SIG // aWNhIE9wZXJhdGlvbnMxJjAkBgNVBAsTHVRoYWxlcyBU
// SIG // U1MgRVNOOkFFMkMtRTMyQi0xQUZDMSUwIwYDVQQDExxN
// SIG // aWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNlMIICIjAN
// SIG // BgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAuExh0n1U
// SIG // xKMzBvkPHer47nryD4UK2GVy1X6bOVC+hLVhDlsIWQ1u
// SIG // X/9a8IRI3zXo/y1oTDuj+rJHyX4OZQn42E0iu7x6swPv
// SIG // M34zIOSPn8lgnWzGEAsRtz9zBrLW9+4w/YhWlXI8hvc7
// SIG // ovqupuL3TXte8BbmNOUDSL+Ou2bBfObGzsH3yY/BELvq
// SIG // wO13KZ9Z1OxKacnqq1u9E9Rhai90STog22lR2MVRSx55
// SIG // FHi/emnZA/IKvsAtEH2K6JmgOyQ7/mDQrWNEA5roUjhQ
// SIG // qLQw1/3wz/CIvc9+FPxX2dxR0nvvYe5VLqv8Q99cOkO6
// SIG // z6V4stGDyFDuO8CwtiSvCC3QrOOugAl33aPD9YZswywW
// SIG // Rk+YGyLI+Fw+kCCUY6h1qOjTj5glz0esmds3ue45WaI2
// SIG // hI9usForM8gy//5tDZXj0KKU1BxA04xpfEy91RZUbc6p
// SIG // dAvEkpYrN2jlpXhMvTD7pgdYyxkVSaWZv7kWp5y9NjWP
// SIG // /CTDGXTC6DWiGcXwPQO66QdVNWxuiGdpfPaEUnWXcKnD
// SIG // Vua1khBAxO4m9wg/1qM6f7HwXf/pHifMej+qB7SUZOiJ
// SIG // ScX+1HmffmZRAFiJXS0qUDk0ZAZW3oX2xLyl0044eHI7
// SIG // Y95GPaw8OlSTeNiNAKl+MyH5OaifsUuyVHOf4rsrE+Zy
// SIG // AuS9e9ERqu5H/10CAwEAAaOCATYwggEyMB0GA1UdDgQW
// SIG // BBRVAolUT3eV3wK/+Luf/wawCPMYpzAfBgNVHSMEGDAW
// SIG // gBSfpxVdAF5iXYP05dJlpxtTNRnpcjBfBgNVHR8EWDBW
// SIG // MFSgUqBQhk5odHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20v
// SIG // cGtpb3BzL2NybC9NaWNyb3NvZnQlMjBUaW1lLVN0YW1w
// SIG // JTIwUENBJTIwMjAxMCgxKS5jcmwwbAYIKwYBBQUHAQEE
// SIG // YDBeMFwGCCsGAQUFBzAChlBodHRwOi8vd3d3Lm1pY3Jv
// SIG // c29mdC5jb20vcGtpb3BzL2NlcnRzL01pY3Jvc29mdCUy
// SIG // MFRpbWUtU3RhbXAlMjBQQ0ElMjAyMDEwKDEpLmNydDAM
// SIG // BgNVHRMBAf8EAjAAMBMGA1UdJQQMMAoGCCsGAQUFBwMI
// SIG // MA0GCSqGSIb3DQEBCwUAA4ICAQAjCREvjT6yXwJYdvkF
// SIG // UqTGGh6RizAY+ciuB6UOBUm0yqq5QC+5pCEa9WSMvbUG
// SIG // zxDCEFBgD93gWGnkiyYcHCazlgZK+E7WxtI3bP++Fb4R
// SIG // JZiWLo/IC9hX12hCZZwYXIGVzC9BVAcNx/zsFqI/9u8u
// SIG // /bhGjDHPad47C4OQNCHrkNqzGYxb4GQq6Psw6o7cEty3
// SIG // MU3Jd4uzBazaFhPRvmBfSn+Ufd6pTNZLgIX9BjrLmZbl
// SIG // c/d2LIAurEr5W29WfW5RMRIEZzO9TaMr/zzdmW/cV6Vd
// SIG // aDTygy5g4O3UXadt1DraUpn5jcD10TVWNnyz/paeleHo
// SIG // jrGCCksqexpelMkUsiYP0HX9pFUgNglWU10r1wEzFwZM
// SIG // 9aX2Rqq3fFRrN3gu8tCX+H1nKK2AobW1vmsKLTH6PyX1
// SIG // LkyvRwTj45a1paeHIR8TGzm3+iY7wpC1MHuzqAqAdDea
// SIG // IVdVlch807VJJ4hDive6AiOQCV9MwiUyhf5v4P8jTGof
// SIG // 8CqjDb3PnLlNSnFm2BFhMZ35oNTEosc37GZHScM83hTN
// SIG // 1E481sLYJrrhhcdtcyNB60juMjqGUD6uQ/7DbMvtv93t
// SIG // Fj5WjxVhMCkkY66EEYgpfFLOCb2ngJJWFuJCIGsCiDfD
// SIG // xGwE4RVYAnoFzoa2OfSqijYg2drdZfpptRRvKxMsAzu3
// SIG // oxkS/TCCB3EwggVZoAMCAQICEzMAAAAVxedrngKbSZkA
// SIG // AAAAABUwDQYJKoZIhvcNAQELBQAwgYgxCzAJBgNVBAYT
// SIG // AlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQH
// SIG // EwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
// SIG // cG9yYXRpb24xMjAwBgNVBAMTKU1pY3Jvc29mdCBSb290
// SIG // IENlcnRpZmljYXRlIEF1dGhvcml0eSAyMDEwMB4XDTIx
// SIG // MDkzMDE4MjIyNVoXDTMwMDkzMDE4MzIyNVowfDELMAkG
// SIG // A1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAO
// SIG // BgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29m
// SIG // dCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0
// SIG // IFRpbWUtU3RhbXAgUENBIDIwMTAwggIiMA0GCSqGSIb3
// SIG // DQEBAQUAA4ICDwAwggIKAoICAQDk4aZM57RyIQt5osvX
// SIG // JHm9DtWC0/3unAcH0qlsTnXIyjVX9gF/bErg4r25Phdg
// SIG // M/9cT8dm95VTcVrifkpa/rg2Z4VGIwy1jRPPdzLAEBjo
// SIG // YH1qUoNEt6aORmsHFPPFdvWGUNzBRMhxXFExN6AKOG6N
// SIG // 7dcP2CZTfDlhAnrEqv1yaa8dq6z2Nr41JmTamDu6Gnsz
// SIG // rYBbfowQHJ1S/rboYiXcag/PXfT+jlPP1uyFVk3v3byN
// SIG // pOORj7I5LFGc6XBpDco2LXCOMcg1KL3jtIckw+DJj361
// SIG // VI/c+gVVmG1oO5pGve2krnopN6zL64NF50ZuyjLVwIYw
// SIG // XE8s4mKyzbnijYjklqwBSru+cakXW2dg3viSkR4dPf0g
// SIG // z3N9QZpGdc3EXzTdEonW/aUgfX782Z5F37ZyL9t9X4C6
// SIG // 26p+Nuw2TPYrbqgSUei/BQOj0XOmTTd0lBw0gg/wEPK3
// SIG // Rxjtp+iZfD9M269ewvPV2HM9Q07BMzlMjgK8QmguEOqE
// SIG // UUbi0b1qGFphAXPKZ6Je1yh2AuIzGHLXpyDwwvoSCtdj
// SIG // bwzJNmSLW6CmgyFdXzB0kZSU2LlQ+QuJYfM2BjUYhEfb
// SIG // 3BvR/bLUHMVr9lxSUV0S2yW6r1AFemzFER1y7435UsSF
// SIG // F5PAPBXbGjfHCBUYP3irRbb1Hode2o+eFnJpxq57t7c+
// SIG // auIurQIDAQABo4IB3TCCAdkwEgYJKwYBBAGCNxUBBAUC
// SIG // AwEAATAjBgkrBgEEAYI3FQIEFgQUKqdS/mTEmr6CkTxG
// SIG // NSnPEP8vBO4wHQYDVR0OBBYEFJ+nFV0AXmJdg/Tl0mWn
// SIG // G1M1GelyMFwGA1UdIARVMFMwUQYMKwYBBAGCN0yDfQEB
// SIG // MEEwPwYIKwYBBQUHAgEWM2h0dHA6Ly93d3cubWljcm9z
// SIG // b2Z0LmNvbS9wa2lvcHMvRG9jcy9SZXBvc2l0b3J5Lmh0
// SIG // bTATBgNVHSUEDDAKBggrBgEFBQcDCDAZBgkrBgEEAYI3
// SIG // FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYwDwYD
// SIG // VR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBTV9lbLj+ii
// SIG // XGJo0T2UkFvXzpoYxDBWBgNVHR8ETzBNMEugSaBHhkVo
// SIG // dHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2NybC9w
// SIG // cm9kdWN0cy9NaWNSb29DZXJBdXRfMjAxMC0wNi0yMy5j
// SIG // cmwwWgYIKwYBBQUHAQEETjBMMEoGCCsGAQUFBzAChj5o
// SIG // dHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpL2NlcnRz
// SIG // L01pY1Jvb0NlckF1dF8yMDEwLTA2LTIzLmNydDANBgkq
// SIG // hkiG9w0BAQsFAAOCAgEAnVV9/Cqt4SwfZwExJFvhnnJL
// SIG // /Klv6lwUtj5OR2R4sQaTlz0xM7U518JxNj/aZGx80HU5
// SIG // bbsPMeTCj/ts0aGUGCLu6WZnOlNN3Zi6th542DYunKmC
// SIG // VgADsAW+iehp4LoJ7nvfam++Kctu2D9IdQHZGN5tggz1
// SIG // bSNU5HhTdSRXud2f8449xvNo32X2pFaq95W2KFUn0CS9
// SIG // QKC/GbYSEhFdPSfgQJY4rPf5KYnDvBewVIVCs/wMnosZ
// SIG // iefwC2qBwoEZQhlSdYo2wh3DYXMuLGt7bj8sCXgU6ZGy
// SIG // qVvfSaN0DLzskYDSPeZKPmY7T7uG+jIa2Zb0j/aRAfbO
// SIG // xnT99kxybxCrdTDFNLB62FD+CljdQDzHVG2dY3RILLFO
// SIG // Ry3BFARxv2T5JL5zbcqOCb2zAVdJVGTZc9d/HltEAY5a
// SIG // GZFrDZ+kKNxnGSgkujhLmm77IVRrakURR6nxt67I6Ile
// SIG // T53S0Ex2tVdUCbFpAUR+fKFhbHP+CrvsQWY9af3LwUFJ
// SIG // fn6Tvsv4O+S3Fb+0zj6lMVGEvL8CwYKiexcdFYmNcP7n
// SIG // tdAoGokLjzbaukz5m/8K6TT4JDVnK+ANuOaMmdbhIurw
// SIG // J0I9JZTmdHRbatGePu1+oDEzfbzL6Xu/OHBE0ZDxyKs6
// SIG // ijoIYn/ZcGNTTY3ugm2lBRDBcQZqELQdVTNYs6FwZvKh
// SIG // ggLLMIICNAIBATCB+KGB0KSBzTCByjELMAkGA1UEBhMC
// SIG // VVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcT
// SIG // B1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
// SIG // b3JhdGlvbjElMCMGA1UECxMcTWljcm9zb2Z0IEFtZXJp
// SIG // Y2EgT3BlcmF0aW9uczEmMCQGA1UECxMdVGhhbGVzIFRT
// SIG // UyBFU046QUUyQy1FMzJCLTFBRkMxJTAjBgNVBAMTHE1p
// SIG // Y3Jvc29mdCBUaW1lLVN0YW1wIFNlcnZpY2WiIwoBATAH
// SIG // BgUrDgMCGgMVADgEd+JNrp4dpvFKMZi91txbfic3oIGD
// SIG // MIGApH4wfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UE
// SIG // AxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAw
// SIG // DQYJKoZIhvcNAQEFBQACBQDnzE2hMCIYDzIwMjMwMzI4
// SIG // MDExNTEzWhgPMjAyMzAzMjkwMTE1MTNaMHQwOgYKKwYB
// SIG // BAGEWQoEATEsMCowCgIFAOfMTaECAQAwBwIBAAICC4Mw
// SIG // BwIBAAICEbwwCgIFAOfNnyECAQAwNgYKKwYBBAGEWQoE
// SIG // AjEoMCYwDAYKKwYBBAGEWQoDAqAKMAgCAQACAwehIKEK
// SIG // MAgCAQACAwGGoDANBgkqhkiG9w0BAQUFAAOBgQBL0w4d
// SIG // r4zc0AjQHT/mELLEDhVnYv5cYoBa6fhG9N/KMg5QIfdD
// SIG // gLwY0ehhUnza7UR00qnipZ0sk0ptB9sLiJqLHNeEdjaG
// SIG // U1AixzNsnGQrlhpG3OerG/QK43QWZGPfjctNXAFX9OlI
// SIG // HxL+MsbZLX+RdPRnczFJaDbIKVtTuN04MDGCBA0wggQJ
// SIG // AgEBMIGTMHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpX
// SIG // YXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYD
// SIG // VQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJjAkBgNV
// SIG // BAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEw
// SIG // AhMzAAABv99uuQQVUihYAAEAAAG/MA0GCWCGSAFlAwQC
// SIG // AQUAoIIBSjAaBgkqhkiG9w0BCQMxDQYLKoZIhvcNAQkQ
// SIG // AQQwLwYJKoZIhvcNAQkEMSIEICt3gYgnSbXtk+2kJ1wO
// SIG // g0a9pSGjs58F29MeEPR3ddc8MIH6BgsqhkiG9w0BCRAC
// SIG // LzGB6jCB5zCB5DCBvQQg/Q4tRz63EiRj4K+19yNUwogB
// SIG // IOsp44CIuBfnZHCvBa4wgZgwgYCkfjB8MQswCQYDVQQG
// SIG // EwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UE
// SIG // BxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENv
// SIG // cnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGlt
// SIG // ZS1TdGFtcCBQQ0EgMjAxMAITMwAAAb/fbrkEFVIoWAAB
// SIG // AAABvzAiBCAeqtHKp9Q1kW8w45hYpTBPj/vReuzk3QZL
// SIG // vV9bSGBySjANBgkqhkiG9w0BAQsFAASCAgCTjcoSBC/2
// SIG // 2N0UbRpK5A2ZI4vcNDIosg+6kEmutUBNUekdX2CPGIwC
// SIG // KP7UHf4TQGsAJAPlr6xJwfAFtQIGFY9a9arp2qu4TkE+
// SIG // FydIeCn92b8KREMmNaXn3YhVN/TOULxkgFH2s5bu8BnB
// SIG // O5te/T3KqwfP4dsMDDtf00NV9Y6x/B4wvfAB6+HjsvyI
// SIG // zf4Kt1HqRUECJzjNLHzFSsFCW1DImI/JTYqts/H0HbGn
// SIG // +oN5Rlj+kqytChMEUk2WJ3WvG0pPVBY8qB64YkE1qF2W
// SIG // mpLj1f7l2D2CItU7yC3FK/malUWJEbHGO+GDZ2hpzR5M
// SIG // YdvMU2YJGvtQ5MvqK1RXbiXA28M4tPWoi5TZ1sZ3kPtQ
// SIG // UWpX/bUPjsUUfAsi5wXte6qyJ4UfDC2a/3Z6SU+7wdW4
// SIG // zPYR4oRAnFWZ1KRQ2jtVmPsBQrkD1SyL0El3mvwIMsvK
// SIG // sc82Zpu8K5EvrBmLS84RJPzw7MGQ/Mscsn+Fi0IfB5rq
// SIG // dilBpmYDGaP8apIbXNQtVzLJ0nIwXADM56pJemBUSIOU
// SIG // SPn4WqQY1r7r+8pr/nrZGEVsbzRD59yzi4E64blleZnR
// SIG // fjMKvXw2Bjahrmn7l7XoxNzI3nNuHGNzUVNkZN8TH6VB
// SIG // Gq5m8tWGavgEHvSP8qB1cJdaU+iT2cudOBl47d66Qewy
// SIG // ShWaNXPOzTbQ9w==
// SIG // End signature block
